rule win_icondown_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.icondown."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.icondown"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 89442420 8b471c d1ee 52 50 83e601 }
            // n = 6, score = 200
            //   89442420             | mov                 dword ptr [esp + 0x20], eax
            //   8b471c               | mov                 eax, dword ptr [edi + 0x1c]
            //   d1ee                 | shr                 esi, 1
            //   52                   | push                edx
            //   50                   | push                eax
            //   83e601               | and                 esi, 1

        $sequence_1 = { 5f 5e 5d b801000000 5b c20400 8b461c }
            // n = 7, score = 200
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp
            //   b801000000           | mov                 eax, 1
            //   5b                   | pop                 ebx
            //   c20400               | ret                 4
            //   8b461c               | mov                 eax, dword ptr [esi + 0x1c]

        $sequence_2 = { 3bc5 7c10 5f 5e 5d b8feffffff 5b }
            // n = 7, score = 200
            //   3bc5                 | cmp                 eax, ebp
            //   7c10                 | jl                  0x12
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp
            //   b8feffffff           | mov                 eax, 0xfffffffe
            //   5b                   | pop                 ebx

        $sequence_3 = { 8b461c 85c0 0f8476010000 8b868c000000 }
            // n = 4, score = 200
            //   8b461c               | mov                 eax, dword ptr [esi + 0x1c]
            //   85c0                 | test                eax, eax
            //   0f8476010000         | je                  0x17c
            //   8b868c000000         | mov                 eax, dword ptr [esi + 0x8c]

        $sequence_4 = { 0fb6da f683c11c450004 7406 8816 46 40 ff01 }
            // n = 7, score = 200
            //   0fb6da               | movzx               ebx, dl
            //   f683c11c450004       | test                byte ptr [ebx + 0x451cc1], 4
            //   7406                 | je                  8
            //   8816                 | mov                 byte ptr [esi], dl
            //   46                   | inc                 esi
            //   40                   | inc                 eax
            //   ff01                 | inc                 dword ptr [ecx]

        $sequence_5 = { b81f85eb51 f7e9 c1fa05 8bca b81f85eb51 c1e91f }
            // n = 6, score = 200
            //   b81f85eb51           | mov                 eax, 0x51eb851f
            //   f7e9                 | imul                ecx
            //   c1fa05               | sar                 edx, 5
            //   8bca                 | mov                 ecx, edx
            //   b81f85eb51           | mov                 eax, 0x51eb851f
            //   c1e91f               | shr                 ecx, 0x1f

        $sequence_6 = { 56 8bf1 33db 57 8975f0 895dec c745e8a4ff4300 }
            // n = 7, score = 200
            //   56                   | push                esi
            //   8bf1                 | mov                 esi, ecx
            //   33db                 | xor                 ebx, ebx
            //   57                   | push                edi
            //   8975f0               | mov                 dword ptr [ebp - 0x10], esi
            //   895dec               | mov                 dword ptr [ebp - 0x14], ebx
            //   c745e8a4ff4300       | mov                 dword ptr [ebp - 0x18], 0x43ffa4

        $sequence_7 = { e8???????? c7462844d04300 833d????????00 7416 }
            // n = 4, score = 200
            //   e8????????           |                     
            //   c7462844d04300       | mov                 dword ptr [esi + 0x28], 0x43d044
            //   833d????????00       |                     
            //   7416                 | je                  0x18

        $sequence_8 = { c3 33c0 5e c3 8b442404 c74050f0b94400 }
            // n = 6, score = 200
            //   c3                   | ret                 
            //   33c0                 | xor                 eax, eax
            //   5e                   | pop                 esi
            //   c3                   | ret                 
            //   8b442404             | mov                 eax, dword ptr [esp + 4]
            //   c74050f0b94400       | mov                 dword ptr [eax + 0x50], 0x44b9f0

        $sequence_9 = { c745f020d04300 c745e810000000 e8???????? 85c0 7403 }
            // n = 5, score = 200
            //   c745f020d04300       | mov                 dword ptr [ebp - 0x10], 0x43d020
            //   c745e810000000       | mov                 dword ptr [ebp - 0x18], 0x10
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   7403                 | je                  5

    condition:
        7 of them and filesize < 5505024
}